@@ -27,6 +27,18 @@ class TestNeuroMLLoader(unittest.TestCase):
         f.close()
         print("Finished test")
 
+    def test_read_neuroml2_file(self):
+        """Test the `read_neuroml2_file` method"""
+        root_dir = os.path.dirname(neuroml.__file__)
+        test_file_path = os.path.join(root_dir, "examples/test_files/MediumNet.net.nml")
+        doc = loaders.read_neuroml2_file(test_file_path, include_includes=True)
+        doc_info = doc.info(show_contents=True, return_format="dict")
+        doc2 = loaders.read_neuroml2_file(test_file_path, include_includes=True)
+        doc2_info = doc2.info(show_contents=True, return_format="dict")
+
+        # check that the ids of the two are the same
+        self.assertEqual(doc_info["id"], doc2_info["id"])
+
     def test_non_neuroml_file(self):
         """Test an non-NeuroML document."""
         root_dir = os.path.dirname(neuroml.__file__)
